diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/wizard/WizardPluginBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/wizard/WizardPluginBase.php
index c3ccf92..5b57d34 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/wizard/WizardPluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/wizard/WizardPluginBase.php
@@ -28,7 +28,7 @@
    *
    * @var string
    */
-  protected $base_table;
+  protected $baseTable;
 
   /**
    * The entity type connected with the wizard.
@@ -38,21 +38,21 @@
    *
    * @var string
    */
-  protected $entity_type;
+  protected $entityType;
 
   /**
    * Contains the information from entity_get_info of the $entity_type.
    *
    * @var array
    */
-  protected $entity_info = array();
+  protected $entityInfo = array();
 
   /**
    * An array of validated view objects, keyed by a hash.
    *
    * @var array
    */
-  protected $validated_views = array();
+  protected $validatedViews = array();
 
   /**
    * The table column used for sorting by create date of this wizard.
@@ -104,7 +104,7 @@
    *
    * @var array()
    */
-  protected $filter_defaults = array(
+  protected $filterDefaults = array(
     'id' => NULL,
     'expose' => array('operator' => FALSE),
     'group' => 1,
@@ -116,13 +116,13 @@
   public function __construct(array $configuration, $plugin_id, array $plugin_definition) {
     parent::__construct($configuration, $plugin_id, $plugin_definition);
 
-    $this->base_table = $this->definition['base_table'];
+    $this->baseTable = $this->definition['baseTable'];
 
     $entities = entity_get_info();
     foreach ($entities as $entity_type => $entity_info) {
-      if (isset($entity_info['base_table']) && $this->base_table == $entity_info['base_table']) {
-        $this->entity_info = $entity_info;
-        $this->entity_type = $entity_type;
+      if (isset($entity_info['baseTable']) && $this->baseTable == $entity_info['baseTable']) {
+        $this->entityInfo = $entity_info;
+        $this->entityType = $entity_type;
       }
     }
   }
@@ -169,7 +169,7 @@ public function getPathFieldsSupplemental() {
   public function getFilters() {
     $filters = array();
 
-    $default = $this->filter_defaults;
+    $default = $this->filterDefaults;
 
     foreach ($this->filters as $name => $info) {
       $default['id'] = $name;
@@ -201,8 +201,8 @@ public function getSorts() {
    * {@inheritdoc} Drupal\views\Plugin\views\wizard\WizardInterface::buildForm().
    */
   public function buildForm(array $form, array &$form_state) {
-    $style_options = views_fetch_plugin_names('style', 'normal', array($this->base_table));
-    $feed_row_options = views_fetch_plugin_names('row', 'feed', array($this->base_table));
+    $style_options = views_fetch_plugin_names('style', 'normal', array($this->baseTable));
+    $feed_row_options = views_fetch_plugin_names('row', 'feed', array($this->baseTable));
     $path_prefix = url(NULL, array('absolute' => TRUE));
 
     // Add filters and sorts which apply to the view as a whole.
@@ -544,7 +544,7 @@ protected function buildFormStyle(array &$form, array &$form_state, $type) {
    */
   protected function rowStyleOptions() {
     // Get all available row plugins by default.
-    $options = views_fetch_plugin_names('row', 'normal', array($this->base_table));
+    $options = views_fetch_plugin_names('row', 'normal', array($this->baseTable));
     return $options;
   }
 
@@ -557,9 +557,9 @@ protected function rowStyleOptions() {
   protected function buildFilters(&$form, &$form_state) {
     module_load_include('inc', 'views_ui', 'admin');
 
-    $bundles = entity_get_bundles($this->entity_type);
+    $bundles = entity_get_bundles($this->entityType);
     // If the current base table support bundles and has more than one (like user).
-    if (isset($this->entity_info['bundle_keys']) && !empty($bundles)) {
+    if (isset($this->entityInfo['bundle_keys']) && !empty($bundles)) {
       // Get all bundles and their human readable names.
       $options = array('all' => t('All'));
       foreach ($bundles as $type => $bundle) {
@@ -623,7 +623,7 @@ protected function instantiateView($form, &$form_state) {
       'id' => $form_state['values']['id'],
       'label' => $form_state['values']['label'],
       'description' => $form_state['values']['description'],
-      'base_table' => $this->base_table,
+      'baseTable' => $this->baseTable,
       'langcode' => language_default()->id,
     );
 
@@ -761,7 +761,7 @@ protected function defaultDisplayOptions() {
     // Add a least one field so the view validates and the user has a preview.
     // The base field can provide a default in its base settings; otherwise,
     // choose the first field with a field handler.
-    $data = Views::viewsData()->get($this->base_table);
+    $data = Views::viewsData()->get($this->baseTable);
     if (isset($data['table']['base']['defaults']['field'])) {
       $default_field = $data['table']['base']['defaults']['field'];
     }
@@ -773,7 +773,7 @@ protected function defaultDisplayOptions() {
       }
     }
     $display_options['fields'][$default_field] = array(
-      'table' => $this->base_table,
+      'table' => $this->baseTable,
       'field' => $default_field,
       'id' => $default_field,
     );
@@ -833,14 +833,14 @@ protected function defaultDisplayFiltersUser(array $form, array &$form_state) {
     $filters = array();
 
     if (!empty($form_state['values']['show']['type']) && $form_state['values']['show']['type'] != 'all') {
-      $bundle_key = $this->entity_info['bundle_keys']['bundle'];
+      $bundle_key = $this->entityInfo['bundle_keys']['bundle'];
       // Figure out the table where $bundle_key lives. It may not be the same as
       // the base table for the view; the taxonomy vocabulary machine_name, for
       // example, is stored in taxonomy_vocabulary, not taxonomy_term_data.
       module_load_include('inc', 'views_ui', 'admin');
-      $fields = Views::viewsDataHelper()->fetchFields($this->base_table, 'filter');
-      if (isset($fields[$this->base_table . '.' . $bundle_key])) {
-        $table = $this->base_table;
+      $fields = Views::viewsDataHelper()->fetchFields($this->baseTable, 'filter');
+      if (isset($fields[$this->baseTable . '.' . $bundle_key])) {
+        $table = $this->baseTable;
       }
       else {
         foreach ($fields as $field_name => $value) {
@@ -928,7 +928,7 @@ protected function defaultDisplaySortsUser($form, $form_state) {
         $column = $column[1];
       }
       else {
-        $table = $this->base_table;
+        $table = $this->baseTable;
         $column = $column[0];
       }
 
@@ -1129,9 +1129,9 @@ protected function retrieveValidatedView(array $form, array &$form_state, $unset
     // @todo Figure out why all this hashing is done. Wouldn't it be easier to
     //   store a single entry and that's it?
     $key = hash('sha256', serialize($form_state['values']));
-    $view = (isset($this->validated_views[$key]) ? $this->validated_views[$key] : NULL);
+    $view = (isset($this->validatedViews[$key]) ? $this->validatedViews[$key] : NULL);
     if ($unset) {
-      unset($this->validated_views[$key]);
+      unset($this->validatedViews[$key]);
     }
     return $view;
   }
@@ -1148,7 +1148,7 @@ protected function retrieveValidatedView(array $form, array &$form_state, $unset
    */
   protected function setValidatedView(array $form, array &$form_state, ViewUI $view) {
     $key = hash('sha256', serialize($form_state['values']));
-    $this->validated_views[$key] = $view;
+    $this->validatedViews[$key] = $view;
   }
 
   /**
@@ -38,21 +38,21 @@
 
   /**
-   * Contains the information from entity_get_info of the $entity_type.
+   * Contains the information from entity_get_info of the $entityType.
    *
    * @var array
